@@ -17,34 +17,92 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Get elevation data from the USGS';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
+sub configure_requires {
+    return +{
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Geo-WebService-Elevation-USGS';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
+    my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
 	},
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
+	dynamic_config	=> 1,
 	resources	=> {
 	    bugtracker	=> {
-                web	=> 'https://github.com/trwyant/perl-Geo-WebService-Elevation-USGS/issues',
-                mailto  => 'wyant@cpan.org',
-            },
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Geo-WebService-Elevation-USGS',
+		# web	=> 'https://github.com/trwyant/perl-Geo-WebService-Elevation-USGS/issues',
+		mailto  => 'wyant@cpan.org',
+	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
 		url	=> 'git://github.com/trwyant/perl-Geo-WebService-Elevation-USGS.git',
 		web	=> 'https://github.com/trwyant/perl-Geo-WebService-Elevation-USGS',
 	    },
-	}
+	},
+	@extra,
     };
 }
 
+sub module_name {
+    return 'Geo::WebService::Elevation::USGS';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
+sub optional_modules {
+    return ( qw{ Time::HiRes } );
+}
+
+sub provides {
+    -d 'lib'
+	or return;
+    local $@ = undef;
+    my $provides = eval {
+	require Module::Metadata;
+	Module::Metadata->provides( version => 2, dir => 'lib' );
+    } or return;
+    return ( provides => $provides );
+}
+
 sub requires {
     my ( undef, @extra ) = @_;		# Invocant unused
 ##  if ( ! $self->distribution() ) {
@@ -56,8 +114,9 @@ sub requires {
 	'LWP::Protocol::https'	=> 0,
 	'LWP::UserAgent'	=> 0,
 	'Scalar::Util'		=> 1.10,
-	'strict'		=> 0,
-	'warnings'		=> 0,
+	constant		=> 0,
+	strict			=> 0,
+	warnings		=> 0,
 	@extra,
     };
 }
@@ -74,6 +133,14 @@ sub build_requires {
     };
 }
 
+sub script_files {
+    return [
+    ];
+}
+
+sub version_from {
+    return 'lib/Geo/WebService/Elevation/USGS.pm';
+}
 
 1;
 
@@ -109,6 +176,39 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
+=head2 build_requires
+
+This method computes and returns a reference to a hash describing the
+modules required to build the C<Geo::WebService::Elevation::USGS>
+package.
+
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -120,6 +220,10 @@ This method instantiates the class.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -127,7 +231,34 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<no_index> and C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
+
+Any arguments will be appended to the generated array.
+
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
+=head2 optional_modules
+
+This method returns the names of any optional modules.
+
+=head2 provides
+
+ use YAML;
+ print Dump( [ $meta->provides() ] );
+
+This method attempts to load L<Module::Metadata|Module::Metadata>. If
+this succeeds, it returns a C<provides> entry suitable for inclusion in
+L<meta_merge()|/meta_merge> data (i.e. C<'provides'> followed by a hash
+reference). If it can not load the required module, it returns nothing.
 
 =head2 requires
 
@@ -148,17 +279,20 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
-=head2 build_requires
+=head2 script_files
 
-This method computes and returns a reference to a hash describing the
-modules required to build the C<Geo::WebService::Elevation::USGS>
-package.
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
 
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -167,12 +301,12 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Geo-WebService-Elevation-USGS/issues>,
-or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Geo-WebService-Elevation-USGS>,
+L<https://github.com/trwyant/perl-Geo-WebService-Elevation-USGS/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
